@@ -1,7 +1,8 @@
 /* Ripped from libgnomeui and adjusted to my needs. Original comments left intact below.
 
-    Copyright (C) 2003-2006 Marcus Bjurman <marbj499@student.liu.se>
- */
+    Copyright (C) 2003-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
+*/
 
  /* gnome-about.h - An about box widget for gnome.
 
@@ -31,8 +32,6 @@
 
 #include <gtk/gtkdialog.h>
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_TYPE_ABOUT_PLUGIN            (gnome_cmd_about_plugin_get_type ())
 #define GNOME_CMD_ABOUT_PLUGIN(object)         (G_TYPE_CHECK_INSTANCE_CAST ((object), GNOME_CMD_TYPE_ABOUT_PLUGIN, GnomeCmdAboutPlugin))
 #define GNOME_CMD_ABOUT_PLUGIN_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_TYPE_ABOUT, GnomeCmdAboutPluginClass))
@@ -40,17 +39,17 @@ G_BEGIN_DECLS
 #define GNOME_CMD_IS_ABOUT_PLUGIN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOME_CMD_TYPE_ABOUT_PLUGIN))
 #define GNOME_CMD_ABOUT_PLUGIN_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOME_CMD_TYPE_ABOUT_PLUGIN, GnomeCmdAboutPluginClass))
 
-typedef struct _GnomeCmdAboutPlugin        GnomeCmdAboutPlugin;
-typedef struct _GnomeCmdAboutPluginClass   GnomeCmdAboutPluginClass;
-typedef struct _GnomeCmdAboutPluginPrivate GnomeCmdAboutPluginPrivate;
+struct GnomeCmdAboutPluginPrivate;
 
-struct _GnomeCmdAboutPlugin {
+struct GnomeCmdAboutPlugin
+{
     GtkDialog parent;
 
     GnomeCmdAboutPluginPrivate *priv;
 };
 
-struct _GnomeCmdAboutPluginClass {
+struct GnomeCmdAboutPluginClass
+{
     GtkDialogClass parent_class;
 };
 
@@ -58,6 +57,4 @@ GType gnome_cmd_about_plugin_get_type (void) G_GNUC_CONST;
 
 GtkWidget *gnome_cmd_about_plugin_new (PluginInfo *info);
 
-G_END_DECLS
-
 #endif // __GNOME_CMD_ABOUT_PLUGIN_H__
