@@ -1,6 +1,7 @@
 /*
-    GNOME Commander - A GNOME based file manager 
-    Copyright (C) 2001-2004 Marcus Bjurman
+    GNOME Commander - A GNOME based file manager
+    Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,44 +15,34 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-*/ 
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 #ifndef __GNOME_CMD_CON_SMB_H__
 #define __GNOME_CMD_CON_SMB_H__
 
 #include "gnome-cmd-con.h"
 
 #define GNOME_CMD_CON_SMB(obj) \
-	GTK_CHECK_CAST (obj, gnome_cmd_con_smb_get_type (), GnomeCmdConSmb)
+    GTK_CHECK_CAST (obj, gnome_cmd_con_smb_get_type (), GnomeCmdConSmb)
 #define GNOME_CMD_CON_SMB_CLASS(klass) \
-	GTK_CHECK_CLASS_CAST (klass, gnome_cmd_con_smb_get_type (), GnomeCmdConSmbClass)
+    GTK_CHECK_CLASS_CAST (klass, gnome_cmd_con_smb_get_type (), GnomeCmdConSmbClass)
 #define GNOME_CMD_IS_CON_SMB(obj) \
     GTK_CHECK_TYPE (obj, gnome_cmd_con_smb_get_type ())
 
 
-typedef struct _GnomeCmdConSmb GnomeCmdConSmb;
-typedef struct _GnomeCmdConSmbClass GnomeCmdConSmbClass;
-typedef struct _GnomeCmdConSmbPrivate GnomeCmdConSmbPrivate;
-
-
-struct _GnomeCmdConSmb
+struct GnomeCmdConSmb
 {
-	GnomeCmdCon parent;
-
-	GnomeCmdConSmbPrivate *priv;
+    GnomeCmdCon parent;
 };
 
-struct _GnomeCmdConSmbClass
+struct GnomeCmdConSmbClass
 {
-	GnomeCmdConClass parent_class;
+    GnomeCmdConClass parent_class;
 };
 
 
-GtkType
-gnome_cmd_con_smb_get_type (void);
+GtkType gnome_cmd_con_smb_get_type ();
 
-GnomeCmdCon *
-gnome_cmd_con_smb_new (void);
+GnomeCmdCon *gnome_cmd_con_smb_new ();
 
-
-#endif //__GNOME_CMD_CON_SMB_H__
+#endif // __GNOME_CMD_CON_SMB_H__
