@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -19,6 +20,7 @@
 
 #include <config.h>
 #include <libgnomevfs/gnome-vfs-mime-monitor.h>
+
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-file-selector.h"
@@ -27,6 +29,7 @@
 #include "gnome-cmd-chown-component.h"
 #include "gnome-cmd-chmod-component.h"
 #include "gnome-cmd-data.h"
+#include "gnome-cmd-treeview.h"
 #include "utils.h"
 #include "imageloader.h"
 #include "tags/gnome-cmd-tags.h"
@@ -37,11 +40,12 @@ using namespace std;
 typedef struct
 {
     GtkWidget *dialog;
-    GnomeCmdFile *finfo;
+    GnomeCmdFile *f;
     GThread *thread;
     GMutex *mutex;
     gboolean count_done;
     gchar *msg;
+    guint updater_proc_id;
 
     GtkWidget *notebook;
     GtkWidget *copy_button;
@@ -64,19 +68,17 @@ typedef struct
 inline const gchar *get_size_disp_string (GnomeVFSFileSize size)
 {
     static gchar s[64];
-    GnomeCmdSizeDispMode mode = gnome_cmd_data_get_size_disp_mode ();
 
-    if (mode == GNOME_CMD_SIZE_DISP_MODE_POWERED)
+    if (gnome_cmd_data.size_disp_mode == GNOME_CMD_SIZE_DISP_MODE_POWERED)
         return create_nice_size_str (size);
 
-    snprintf (s, sizeof (s), ngettext("%s byte","%s bytes",size), size2string (size, mode));
+    snprintf (s, sizeof (s), ngettext("%s byte","%s bytes",size), size2string (size, gnome_cmd_data.size_disp_mode));
     return s;
 }
 
 
 static void calc_tree_size_r (GnomeCmdFilePropsDialogPrivate *data, GnomeVFSURI *uri)
 {
-    GnomeVFSFileInfoOptions infoOpts = GNOME_VFS_FILE_INFO_DEFAULT;
     GList *list = NULL;
     gchar *uri_str;
 
@@ -87,7 +89,7 @@ static void calc_tree_size_r (GnomeCmdFilePropsDialogPrivate *data, GnomeVFSURI
     uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
     if (!uri_str) return;
 
-    GnomeVFSResult result = gnome_vfs_directory_list_load (&list, uri_str, infoOpts);
+    GnomeVFSResult result = gnome_vfs_directory_list_load (&list, uri_str, GNOME_VFS_FILE_INFO_DEFAULT);
 
     if (result != GNOME_VFS_OK) return;
     if (!list) return;
@@ -139,10 +141,12 @@ static void calc_tree_size_func (GnomeCmdFilePropsDialogPrivate *data)
 // Tells the thread to exit and then waits for it to do so.
 static gboolean join_thread_func (GnomeCmdFilePropsDialogPrivate *data)
 {
+    g_source_remove (data->updater_proc_id);
+    
     if (data->thread)
         g_thread_join (data->thread);
 
-    gnome_cmd_file_unref (data->finfo);
+    gnome_cmd_file_unref (data->f);
     g_free (data);
 
     return FALSE;
@@ -184,16 +188,16 @@ static void do_calc_tree_size (GnomeCmdFilePropsDialogPrivate *data)
 
     data->thread = g_thread_create ((PthreadFunc) calc_tree_size_func, data, TRUE, NULL);
 
-    g_timeout_add (gnome_cmd_data_get_gui_update_rate (), (GSourceFunc) update_count_status, data);
+    data->updater_proc_id = g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_count_status, data);
 }
 
 
 static void on_change_default_app (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
 {
 
-    edit_mimetypes (data->finfo->info->mime_type, TRUE);
+    edit_mimetypes (data->f->info->mime_type, TRUE);
 
-    GnomeVFSMimeApplication *vfs_app = gnome_vfs_mime_get_default_application (data->finfo->info->mime_type);
+    GnomeVFSMimeApplication *vfs_app = gnome_vfs_mime_get_default_application (data->f->info->mime_type);
 
     gchar *appname = vfs_app ? vfs_app->name : g_strdup (_("No default application registered"));
 
@@ -213,20 +217,20 @@ static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
 
     const gchar *filename = gtk_entry_get_text (GTK_ENTRY (data->filename_entry));
 
-    if (strcmp (filename, gnome_cmd_file_get_name (data->finfo)) != 0)
+    if (strcmp (filename, gnome_cmd_file_get_name (data->f)) != 0)
     {
-        result = gnome_cmd_file_rename (data->finfo, filename);
+        result = gnome_cmd_file_rename (data->f, filename);
 
         if (result==GNOME_VFS_OK)
-            gnome_cmd_file_list_focus_file (gnome_cmd_main_win_get_fs (main_win, ACTIVE)->list, filename, TRUE);
+            gnome_cmd_main_win_get_fs (main_win, ACTIVE)->file_list()->focus_file(filename, TRUE);
     }
 
     if (result == GNOME_VFS_OK)
     {
         GnomeVFSFilePermissions perms = gnome_cmd_chmod_component_get_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component));
 
-        if (perms != data->finfo->info->permissions)
-            result = gnome_cmd_file_chmod (data->finfo, perms);
+        if (perms != data->f->info->permissions)
+            result = gnome_cmd_file_chmod (data->f, perms);
     }
 
     if (result == GNOME_VFS_OK)
@@ -234,13 +238,13 @@ static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
         uid_t uid = gnome_cmd_chown_component_get_owner (GNOME_CMD_CHOWN_COMPONENT (data->chown_component));
         gid_t gid = gnome_cmd_chown_component_get_group (GNOME_CMD_CHOWN_COMPONENT (data->chown_component));
 
-        if (uid == data->finfo->info->uid)
+        if (uid == data->f->info->uid)
             uid = -1;
-        if (gid == data->finfo->info->gid)
+        if (gid == data->f->info->gid)
             gid = -1;
 
         if (uid != -1 || gid != -1)
-            result = gnome_cmd_file_chown (data->finfo, uid, gid);
+            result = gnome_cmd_file_chown (data->f, uid, gid);
     }
 
     if (result != GNOME_VFS_OK)
@@ -265,7 +269,7 @@ static void on_copy_clipboard (GtkButton *button, GnomeCmdFilePropsDialogPrivate
 
     string s;
 
-    for (GnomeCmdFileMetadata::METADATA_COLL::const_iterator i=data->finfo->metadata->begin(); i!=data->finfo->metadata->end(); ++i)
+    for (GnomeCmdFileMetadata::METADATA_COLL::const_iterator i=data->f->metadata->begin(); i!=data->f->metadata->end(); ++i)
         for (set<std::string>::const_iterator j=i->second.begin(); j!=i->second.end(); ++j)
         {
             s += gcmd_tags_get_name(i->first);
@@ -369,21 +373,21 @@ inline GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     table = create_table (dialog, 6, 3);
     gtk_container_add (GTK_CONTAINER (space_frame), table);
 
-    label = create_bold_label (dialog, _("Filename:"));
+    label = create_bold_label (dialog, _("File name:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    fname = get_utf8 (gnome_cmd_file_get_name (data->finfo));
+    fname = get_utf8 (gnome_cmd_file_get_name (data->f));
     data->filename_entry = create_entry (dialog, "filename_entry", fname);
     g_free (fname);
     table_add (table, data->filename_entry, 1, y++, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND));
     gtk_editable_set_position (GTK_EDITABLE (data->filename_entry), 0);
 
-    if (data->finfo->info->symlink_name)
+    if (data->f->info->symlink_name)
     {
         label = create_bold_label (dialog, _("Symlink target:"));
         table_add (table, label, 0, y, GTK_FILL);
 
-        label = create_label (dialog, data->finfo->info->symlink_name);
+        label = create_label (dialog, data->f->info->symlink_name);
         table_add (table, label, 1, y++, GTK_FILL);
     }
 
@@ -392,23 +396,23 @@ inline GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     label = create_bold_label (dialog, _("Type:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, gnome_cmd_file_get_mime_type_desc (data->finfo));
+    label = create_label (dialog, gnome_cmd_file_get_mime_type_desc (data->f));
     table_add (table, label, 1, y++, GTK_FILL);
 
 
     label = create_bold_label (dialog, _("MIME Type:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, gnome_cmd_file_get_mime_type (data->finfo));
+    label = create_label (dialog, gnome_cmd_file_get_mime_type (data->f));
     table_add (table, label, 1, y++, GTK_FILL);
 
 
-    if (data->finfo->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
+    if (data->f->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY)
     {
         label = create_bold_label (dialog, _("Opens with:"));
         table_add (table, label, 0, y, GTK_FILL);
 
-        GnomeVFSMimeApplication *vfs_app = gnome_cmd_app_get_default_application (data->finfo);
+        GnomeVFSMimeApplication *vfs_app = gnome_cmd_app_get_default_application (data->f);
 
         if (vfs_app)
         {
@@ -433,13 +437,13 @@ inline GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     label = create_bold_label (dialog, _("Modified:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, gnome_cmd_file_get_mdate (data->finfo, TRUE));
+    label = create_label (dialog, gnome_cmd_file_get_mdate (data->f, TRUE));
     table_add (table, label, 1, y++, GTK_FILL);
 
     label = create_bold_label (dialog, _("Accessed:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, gnome_cmd_file_get_adate (data->finfo, TRUE));
+    label = create_label (dialog, gnome_cmd_file_get_adate (data->f, TRUE));
     table_add (table, label, 1, y++, GTK_FILL);
 
 
@@ -449,24 +453,26 @@ inline GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     label = create_bold_label (dialog, _("Size:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, get_size_disp_string (data->finfo->info->size));
+    label = create_label (dialog, get_size_disp_string (data->f->info->size));
     table_add (table, label, 1, y++, GTK_FILL);
-    if (data->finfo->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
+    if (data->f->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
         do_calc_tree_size (data);
 
     data->size_label = label;
 
-    gcmd_tags_bulk_load (data->finfo);
+    gcmd_tags_bulk_load (data->f);
 
-    if (data->finfo->metadata)
+    if (data->f->metadata)
     {
-        add_tag (dialog, table, y, *data->finfo->metadata, TAG_FILE_DESCRIPTION);
-        add_tag (dialog, table, y, *data->finfo->metadata, TAG_FILE_PUBLISHER);
-        add_width_height_tag (dialog, table, y, *data->finfo->metadata);
-        add_tag (dialog, table, y, *data->finfo->metadata, TAG_AUDIO_ALBUMARTIST);
-        add_tag (dialog, table, y, *data->finfo->metadata, TAG_AUDIO_TITLE);
-        add_tag (dialog, table, y, *data->finfo->metadata, TAG_AUDIO_BITRATE, " kbps");
-        add_tag (dialog, table, y, *data->finfo->metadata, TAG_AUDIO_DURATIONMMSS);
+        add_tag (dialog, table, y, *data->f->metadata, TAG_FILE_DESCRIPTION);
+        add_tag (dialog, table, y, *data->f->metadata, TAG_FILE_PUBLISHER);
+        add_tag (dialog, table, y, *data->f->metadata, TAG_DOC_TITLE);
+        add_tag (dialog, table, y, *data->f->metadata, TAG_DOC_PAGECOUNT);
+        add_width_height_tag (dialog, table, y, *data->f->metadata);
+        add_tag (dialog, table, y, *data->f->metadata, TAG_AUDIO_ALBUMARTIST);
+        add_tag (dialog, table, y, *data->f->metadata, TAG_AUDIO_TITLE);
+        add_tag (dialog, table, y, *data->f->metadata, TAG_AUDIO_BITRATE, " kbps");
+        add_tag (dialog, table, y, *data->f->metadata, TAG_AUDIO_DURATIONMMSS);
     }
 
     return space_frame;
@@ -487,7 +493,7 @@ inline GtkWidget *create_permissions_tab (GnomeCmdFilePropsDialogPrivate *data)
                               (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (data->chown_component);
     gnome_cmd_chown_component_set (GNOME_CMD_CHOWN_COMPONENT (data->chown_component),
-        data->finfo->info->uid, data->finfo->info->gid);
+        data->f->info->uid, data->f->info->gid);
 
     GtkWidget *cat = create_category (data->dialog, data->chown_component, _("Owner and group"));
     gtk_box_pack_start (GTK_BOX (vbox), cat, TRUE, TRUE, 0);
@@ -497,7 +503,7 @@ inline GtkWidget *create_permissions_tab (GnomeCmdFilePropsDialogPrivate *data)
     gtk_widget_ref (data->chmod_component);
     gtk_object_set_data_full (GTK_OBJECT (data->dialog), "chmod_component", data->chmod_component, (GtkDestroyNotify) gtk_widget_unref);
     gtk_widget_show (data->chmod_component);
-    gnome_cmd_chmod_component_set_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component), data->finfo->info->permissions);
+    gnome_cmd_chmod_component_set_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component), data->f->info->permissions);
 
     cat = create_category (data->dialog, data->chmod_component, _("Access permissions"));
     gtk_box_pack_start (GTK_BOX (vbox), cat, TRUE, TRUE, 0);
@@ -517,7 +523,7 @@ enum
 } ;
 
 
-static GtkTreeModel *create_and_fill_model (GnomeCmdFile *finfo)
+static GtkTreeModel *create_and_fill_model (GnomeCmdFile *f)
 {
     GtkTreeStore *treestore = gtk_tree_store_new (NUM_COLS,
                                                   G_TYPE_UINT,
@@ -526,14 +532,14 @@ static GtkTreeModel *create_and_fill_model (GnomeCmdFile *finfo)
                                                   G_TYPE_STRING,
                                                   G_TYPE_STRING);
 
-    if (!gcmd_tags_bulk_load (finfo))
+    if (!gcmd_tags_bulk_load (f))
         return GTK_TREE_MODEL (treestore);
 
     GnomeCmdTagClass prev_tagclass = TAG_NONE_CLASS;
 
     GtkTreeIter toplevel;
 
-    for (GnomeCmdFileMetadata::METADATA_COLL::const_iterator i=finfo->metadata->begin(); i!=finfo->metadata->end(); ++i)
+    for (GnomeCmdFileMetadata::METADATA_COLL::const_iterator i=f->metadata->begin(); i!=f->metadata->end(); ++i)
     {
         const GnomeCmdTag t = i->first;
         GnomeCmdTagClass curr_tagclass = gcmd_tags_get_class(t);
@@ -570,36 +576,7 @@ static GtkTreeModel *create_and_fill_model (GnomeCmdFile *finfo)
 }
 
 
-inline GtkTreeViewColumn *create_new_column (GtkTreeView *view, GtkCellRenderer *&renderer, gint COL_ID, const gchar *title=NULL)
-{
-    renderer = gtk_cell_renderer_text_new ();
-
-    GtkTreeViewColumn *col = gtk_tree_view_column_new_with_attributes (title,
-                                                                       renderer,
-                                                                       "text", COL_ID,
-                                                                       NULL);
-
-    g_object_set (col,
-                  "clickable", TRUE,
-                  "resizable", TRUE,
-                  NULL);
-
-    // pack tree view column into tree view
-    gtk_tree_view_append_column (GTK_TREE_VIEW (view), col);
-
-    return col;
-}
-
-
-inline GtkTreeViewColumn *create_new_column (GtkTreeView *view, gint COL_ID, const gchar *title=NULL)
-{
-    GtkCellRenderer *renderer = NULL;
-
-    return create_new_column (view, renderer, COL_ID, title);
-}
-
-
-static GtkWidget *create_view_and_model (GnomeCmdFile *finfo)
+static GtkWidget *create_view_and_model (GnomeCmdFile *f)
 {
     GtkWidget *view = gtk_tree_view_new ();
 
@@ -614,7 +591,7 @@ static GtkWidget *create_view_and_model (GnomeCmdFile *finfo)
 
     GtkTooltips *tips = gtk_tooltips_new ();
 
-    col = create_new_column (GTK_TREE_VIEW (view), renderer, COL_TYPE, _("Type"));
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_TYPE, _("Type"));
     gtk_tooltips_set_tip (tips, col->button, _("Metadata namespace"), NULL);
 
     g_object_set (renderer,
@@ -622,13 +599,13 @@ static GtkWidget *create_view_and_model (GnomeCmdFile *finfo)
                   "weight", PANGO_WEIGHT_BOLD,
                   NULL);
 
-    col = create_new_column (GTK_TREE_VIEW (view), COL_NAME, _("Name"));
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), COL_NAME, _("Name"));
     gtk_tooltips_set_tip (tips, col->button, _("Tag name"), NULL);
 
-    col = create_new_column (GTK_TREE_VIEW (view), COL_VALUE, _("Value"));
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), COL_VALUE, _("Value"));
     gtk_tooltips_set_tip (tips, col->button, _("Tag value"), NULL);
 
-    col = create_new_column (GTK_TREE_VIEW (view), renderer, COL_DESC, _("Description"));
+    col = gnome_cmd_treeview_create_new_text_column (GTK_TREE_VIEW (view), renderer, COL_DESC, _("Description"));
     gtk_tooltips_set_tip (tips, col->button, _("Metadata tag description"), NULL);
 
     g_object_set (renderer,
@@ -638,7 +615,7 @@ static GtkWidget *create_view_and_model (GnomeCmdFile *finfo)
                   "ellipsize", PANGO_ELLIPSIZE_END,
                   NULL);
 
-    GtkTreeModel *model = create_and_fill_model (finfo);
+    GtkTreeModel *model = create_and_fill_model (f);
 
     gtk_tree_view_set_model (GTK_TREE_VIEW (view), model);
 
@@ -663,7 +640,7 @@ inline GtkWidget *create_metadata_tab (GnomeCmdFilePropsDialogPrivate *data)
 
     gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (scrolledwindow), TRUE, TRUE, 0);
 
-    GtkWidget *view = create_view_and_model (data->finfo);
+    GtkWidget *view = create_view_and_model (data->f);
 
     gtk_container_add (GTK_CONTAINER (scrolledwindow), view);
 
@@ -673,12 +650,12 @@ inline GtkWidget *create_metadata_tab (GnomeCmdFilePropsDialogPrivate *data)
 }
 
 
-GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *finfo)
+GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *f)
 {
-    g_return_val_if_fail (finfo != NULL, NULL);
-    g_return_val_if_fail (finfo->info != NULL, NULL);
+    g_return_val_if_fail (f != NULL, NULL);
+    g_return_val_if_fail (f->info != NULL, NULL);
 
-    if (strcmp (finfo->info->name, "..") == 0)
+    if (strcmp (f->info->name, "..") == 0)
         return NULL;
 
     GnomeCmdFilePropsDialogPrivate *data = g_new0 (GnomeCmdFilePropsDialogPrivate, 1);
@@ -691,12 +668,12 @@ GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *finfo)
     GtkWidget *notebook = gtk_notebook_new ();
 
     data->dialog = GTK_WIDGET (dialog);
-    data->finfo = finfo;
-    data->uri = gnome_cmd_file_get_uri (finfo);
+    data->f = f;
+    data->uri = gnome_cmd_file_get_uri (f);
     data->mutex = g_mutex_new ();
     data->msg = NULL;
     data->notebook = notebook;
-    gnome_cmd_file_ref (finfo);
+    gnome_cmd_file_ref (f);
 
     gtk_widget_ref (notebook);
     gtk_object_set_data_full (GTK_OBJECT (dialog), "notebook", notebook, (GtkDestroyNotify) gtk_widget_unref);
