@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -27,23 +28,21 @@
 #define GNOME_CMD_IS_MAIN_WIN(obj) \
     GTK_CHECK_TYPE(obj, gnome_cmd_main_win_get_type ())
 
-typedef struct _GnomeCmdMainWin GnomeCmdMainWin;
-typedef struct _GnomeCmdMainWinPrivate GnomeCmdMainWinPrivate;
-typedef struct _GnomeCmdMainWinClass GnomeCmdMainWinClass;
+struct GnomeCmdMainWinPrivate;
 
 #include "gnome-cmd-file-selector.h"
+#include "gnome-cmd-advrename-dialog.h"
 #include "gnome-cmd-cmdline.h"
 #include "plugin_manager.h"
 
-G_BEGIN_DECLS
-
-struct _GnomeCmdMainWin
+struct GnomeCmdMainWin
 {
     GnomeApp parent;
+    GnomeCmdAdvrenameDialog *advrename_dlg;
     GnomeCmdMainWinPrivate *priv;
 };
 
-struct _GnomeCmdMainWinClass
+struct GnomeCmdMainWinClass
 {
     GnomeAppClass parent_class;
 
@@ -54,21 +53,17 @@ struct _GnomeCmdMainWinClass
 extern GnomeCmdMainWin *main_win;
 
 
-GtkType gnome_cmd_main_win_get_type (void);
+GtkType gnome_cmd_main_win_get_type ();
 
-GtkWidget *gnome_cmd_main_win_new (void);
+GtkWidget *gnome_cmd_main_win_new ();
 
 GnomeCmdFileSelector *gnome_cmd_main_win_get_fs (GnomeCmdMainWin *mw, FileSelectorID fs);
-gboolean gnome_cmd_main_win_is_fs_active (GnomeCmdMainWin *mw, FileSelectorID fs);
 void gnome_cmd_main_win_switch_fs (GnomeCmdMainWin *mw, GnomeCmdFileSelector *fs);
 
 GnomeCmdCmdline *gnome_cmd_main_win_get_cmdline (GnomeCmdMainWin *mw);
 
 void gnome_cmd_main_win_update_style (GnomeCmdMainWin *mw);
 
-void gnome_cmd_main_win_hide_embterm (GnomeCmdMainWin *mw);
-void gnome_cmd_main_win_show_embterm (GnomeCmdMainWin *mw);
-
 void gnome_cmd_main_win_new_cwd (GnomeCmdMainWin *mw, const gchar *cwd);
 
 void gnome_cmd_main_win_focus_cmdline (GnomeCmdMainWin *mw);
@@ -78,7 +73,6 @@ void gnome_cmd_main_win_refocus (GnomeCmdMainWin *mw);
 gboolean gnome_cmd_main_win_keypressed (GnomeCmdMainWin *mw, GdkEventKey *event);
 
 void gnome_cmd_main_win_update_bookmarks (GnomeCmdMainWin *mw);
-void gnome_cmd_main_win_update_connections (GnomeCmdMainWin *mw);
 void gnome_cmd_main_win_update_toolbar_visibility (GnomeCmdMainWin *mw);
 void gnome_cmd_main_win_update_cmdline_visibility (GnomeCmdMainWin *mw);
 void gnome_cmd_main_win_update_buttonbar_visibility (GnomeCmdMainWin *mw);
@@ -92,6 +86,4 @@ void gnome_cmd_main_win_set_cap_state (GnomeCmdMainWin *mw, gboolean state);
 
 void gnome_cmd_main_win_set_equal_panes (GnomeCmdMainWin *mw);
 
-G_END_DECLS
-
 #endif // __GNOME_CMD_MAIN_WIN_H__
