@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,8 +23,6 @@
 
 #include "gnome-cmd-dir.h"
 
-G_BEGIN_DECLS
-
 #define GNOME_CMD_MKDIR_DIALOG(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_mkdir_dialog_get_type (), GnomeCmdMkdirDialog)
 #define GNOME_CMD_MKDIR_DIALOG_CLASS(klass) \
@@ -32,31 +31,25 @@ G_BEGIN_DECLS
     GTK_CHECK_TYPE (obj, gnome_cmd_mkdir_dialog_get_type ())
 
 
-typedef struct _GnomeCmdMkdirDialog GnomeCmdMkdirDialog;
-typedef struct _GnomeCmdMkdirDialogPrivate GnomeCmdMkdirDialogPrivate;
-typedef struct _GnomeCmdMkdirDialogClass GnomeCmdMkdirDialogClass;
+struct GnomeCmdMkdirDialogPrivate;
 
 
-
-struct _GnomeCmdMkdirDialog
+struct GnomeCmdMkdirDialog
 {
     GnomeCmdStringDialog parent;
+
     GnomeCmdMkdirDialogPrivate *priv;
 };
 
 
-struct _GnomeCmdMkdirDialogClass
+struct GnomeCmdMkdirDialogClass
 {
     GnomeCmdStringDialogClass parent_class;
 };
 
 
-GtkWidget*
-gnome_cmd_mkdir_dialog_new (GnomeCmdDir *dir);
+GtkWidget *gnome_cmd_mkdir_dialog_new (GnomeCmdDir *dir);
 
-GtkType
-gnome_cmd_mkdir_dialog_get_type (void);
-
-G_END_DECLS
+GtkType gnome_cmd_mkdir_dialog_get_type ();
 
 #endif // __GNOME_CMD_MKDIR_DIALOG_H__
