@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2009 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,12 +21,9 @@
 #ifndef __GNOME_CMD_STYLE_H__
 #define __GNOME_CMD_STYLE_H__
 
-G_BEGIN_DECLS
-
 extern GtkStyle *list_style, *sel_list_style;
+extern GtkStyle *alt_list_style, *alt_sel_list_style;
 
-void gnome_cmd_style_create (void);
-
-G_END_DECLS
+void gnome_cmd_style_create ();
 
 #endif // __GNOME_CMD_STYLE_H__
